indexing

   description: "Class that describes a host on the network."

   author: "Berend de Boer"
   date: "$Date: 2001/12/27 $"
   revision: "$Revision: #1 $"


class

   SUS_HOST


inherit

   SUS_BASE

   SAPI_NETDB

   EPX_POINTER_ADD


creation

   make_from_name


feature -- creation

   make_from_name (a_name: STRING) is
      require
         valid_name: a_name /= Void and then not a_name.is_empty
      local
         p: POINTER
         pptr: POINTER
         aptr: POINTER
         ip_address: SUS_IP4_ADDRESS
         buf: STDC_BUFFER
      do
         p := posix_gethostbyname (sh.string_to_pointer (a_name))
         name := sh.pointer_to_string (posix_hostent_h_name (p))
         aliases := ah.pointer_to_string_array (posix_hostent_h_aliases (p))
         address_type := posix_hostent_h_addrtype (p)
         length := posix_hostent_h_length (p)
         create addresses.make (0, -1)
         from
            pptr := posix_hostent_h_addr_list (p)
            aptr := posix_pointer_contents (pptr)
         until
            aptr = default_pointer
         loop
            create buf.make_from_pointer (aptr, 4, False)
            create ip_address.make_from_integer (buf.peek_uint32_native (0))
            addresses.force (ip_address, addresses.upper + 1)
            pptr := posix_pointer_advance (pptr)
            aptr := posix_pointer_contents (pptr)
         end
      end


feature

   name: STRING
         -- official (canonical) name of host

   aliases: ARRAY[STRING]
         -- alias names

   address_type: INTEGER
         -- host address type: AF_INET or AF_INET6

   length: INTEGER
         -- length of address: 4 or 16

   addresses: ARRAY[SUS_IP_ADDRESS]
         -- array with IPv4 or IPv6 addresses


invariant

   has_name: name /= Void and then not name.is_empty
   has_at_least_one_ip_address: addresses /= Void and addresses.count > 0

end
